@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import configparser
 import json
 import logging
@@ -5,7 +7,7 @@ import os
 import pathlib
 from dataclasses import replace
 from decimal import Decimal, InvalidOperation
-from typing import IO, Any, Dict, Optional, Sequence, Tuple
+from typing import IO, Any, Sequence
 
 import click
 import yaml
@@ -21,6 +23,7 @@ from apolo_sdk import (
     _ConfigCluster,
     _OrgCluster,
     _OrgUserRoleType,
+    _PatchNodePoolSizeRequest,
     _Project,
     _ProjectUser,
     _ProjectUserRoleType,
@@ -41,6 +44,7 @@ from .formatters.admin import (
     ClusterUserWithInfoFormatter,
     OrgClusterFormatter,
     OrgClustersFormatter,
+    OrgFormatter,
     OrgsFormatter,
     OrgUserFormatter,
     ProjectFormatter,
@@ -56,6 +60,18 @@ log = logging.getLogger(__name__)
 UNLIMITED = "unlimited"
 
 
+def _get_org_or_none(root: Root, org: str | None) -> str | None:
+    org_name = org or root.client.config.org_name
+    return None if org_name == "NO_ORG" else org_name
+
+
+def _get_org(root: Root, org: str | None) -> str:
+    org_name = _get_org_or_none(root, org)
+    if not org_name:
+        raise ValueError("Org name is required")
+    return org_name
+
+
 @group()
 def admin() -> None:
     """Cluster administration commands."""
@@ -70,7 +86,7 @@ async def get_clusters(root: Root) -> None:
     with root.status("Fetching the list of clusters"):
         config_clusters = await root.client._clusters.list()
         admin_clusters = await root.client._admin.list_clusters()
-    clusters: Dict[str, Tuple[Optional[_Cluster], Optional[_ConfigCluster]]] = {}
+    clusters: dict[str, tuple[_Cluster | None, _ConfigCluster | None]] = {}
     for config_cluster in config_clusters:
         clusters[config_cluster.name] = (None, config_cluster)
     for admin_cluster in admin_clusters:
@@ -95,13 +111,13 @@ async def get_clusters(root: Root) -> None:
 @argument("cluster_name", required=True, type=str)
 @argument("node_pool_name", required=True, type=str)
 async def update_node_pool(
-    root: Root, cluster_name: str, node_pool_name: str, idle_size: Optional[int]
+    root: Root, cluster_name: str, node_pool_name: str, idle_size: int | None
 ) -> None:
     """
     Update cluster node pool.
     """
     await root.client._clusters.update_node_pool(
-        cluster_name, node_pool_name, idle_size=idle_size
+        cluster_name, node_pool_name, _PatchNodePoolSizeRequest(idle_size=idle_size)
     )
     if not root.quiet:
         root.print(
@@ -321,17 +337,18 @@ credentials:
   access_key_id: {access_key_id}
   secret_access_key: {secret_access_key}
 node_pools:
-- id: m5_2xlarge_8
+- machine_type: m5.2xlarge
   min_size: 1
   max_size: 4
-- id: p2_xlarge_4
+- machine_type: p2.xlarge
   min_size: 1
   max_size: 4
-- id: p3_2xlarge_8
+- machine_type: p3.2xlarge
   min_size: 0
   max_size: 1
 storage:
-  id: generalpurpose_bursting
+  performance_mode: generalPurpose
+  throughput_mode: bursting
   instances:
   - {}
 """
@@ -377,21 +394,21 @@ zones:
 project: {project_name}
 credentials: {credentials}
 node_pools:
-- id: n1_highmem_8
+- machine_type: n1-highmem-8
   min_size: 1
   max_size: 4
-- id: n1_highmem_8
+- machine_type: n1-highmem-8
   min_size: 1
   max_size: 4
-  gpu: 1
-  gpu_model: nvidia-tesla-k80
-- id: n1_highmem_8
+  nvidia_gpu: 1
+  nvidia_gpu_model: nvidia-tesla-k80
+- machine_type: n1-highmem-8
   min_size: 0
   max_size: 1
-  gpu: 1
-  gpu_model: nvidia-tesla-v100
+  nvidia_gpu: 1
+  nvidia_gpu_model: nvidia-tesla-v100
 storage:
-  id: gcs-nfs
+  tier: PREMIUM
   instances:
   - {}
 """
@@ -421,17 +438,17 @@ credentials:
   client_id: {client_id}
   client_secret: {client_secret}
 node_pools:
-- id: standard_d8_v3_8
+- machine_type: Standard_D8_v3
   min_size: 1
   max_size: 4
-- id: standard_nc6_6
+- machine_type: Standard_NC6
   min_size: 1
   max_size: 4
-- id: standard_nc6s_v3_6
+- machine_type: Standard_NC6s_v3
   min_size: 0
   max_size: 1
 storage:
-  id: premium_lrs
+  tier: Premium
   instances:
   - size: {file_share_size}
 """
@@ -470,14 +487,14 @@ credentials:
   user: {user}
   password: {password}
 node_pools:
-- id: {kubernetes_node_pool_id}
+- machine_type: {kubernetes_node_pool_machine_type}
   role: kubernetes
   name: kubernetes
   min_size: 3
   max_size: 3
   disk_type: {storage_profile_name}
   disk_size: 40_000_000_000
-- id: {platform_node_pool_id}
+- machine_type: {platform_node_pool_machine_type}
   role: platform
   name: platform
   min_size: 3
@@ -549,8 +566,12 @@ async def generate_vcd(root: Root, session: PromptSession[str]) -> str:
     )
     storage_size_gb = await session.prompt_async("Storage size (Gb): ")
     args["storage_size"] = storage_size_gb * 10**9
-    args["kubernetes_node_pool_id"] = cloud_provider.kubernetes_node_pool_id
-    args["platform_node_pool_id"] = cloud_provider.platform_node_pool_id
+    args["kubernetes_node_pool_id"] = await session.prompt_async(
+        "Kubernetes node pool machine type: "
+    )
+    args["platform_node_pool_id"] = await session.prompt_async(
+        "Platform node pool machine type: "
+    )
     return VCD_TEMPLATE.format_map(args)
 
 
@@ -571,9 +592,9 @@ async def generate_vcd(root: Root, session: PromptSession[str]) -> str:
 @argument("cluster_name", required=False, default=None, type=str)
 async def get_cluster_users(
     root: Root,
-    org: Optional[str],
+    org: str | None,
     details: bool,
-    cluster_name: Optional[str],
+    cluster_name: str | None,
 ) -> None:
     """
     List users in specified cluster
@@ -585,7 +606,7 @@ async def get_cluster_users(
         users = await root.client._admin.list_cluster_users(  # type: ignore
             cluster_name=cluster_name,
             with_user_info=details,
-            org_name=org,
+            org_name=_get_org_or_none(root, org),
         )
         users = sorted(users, key=lambda user: (user.user_name, user.org_name or ""))
     with root.pager():
@@ -612,15 +633,6 @@ async def get_cluster_users(
     type=str,
     help="org name for org-cluster users",
 )
-@option(
-    "-c",
-    "--credits",
-    metavar="AMOUNT",
-    type=str,
-    default=None,
-    show_default=True,
-    help="Credits amount to set (`unlimited' stands for no limit)",
-)
 @option(
     "-j",
     "--jobs",
@@ -634,22 +646,17 @@ async def add_cluster_user(
     root: Root,
     cluster_name: str,
     user_name: str,
-    role: Optional[str],
-    credits: Optional[str],
-    jobs: Optional[str],
-    org: Optional[str],
+    role: str | None,
+    jobs: str | None,
+    org: str | None,
 ) -> None:
     """
-    Add user access to specified cluster.
+    Add user access to a specified cluster.
 
-    The command supports one of 3 user roles: admin, manager or user.
+    The command supports one of three user roles: admin, manager or user.
     """
     # Use cluster defaults credits/quota for "user-like" roles.
     # Unlimited for other roles.
-    if credits is None and role in (None, "user", "member"):
-        balance = None
-    else:
-        balance = _Balance(credits=_parse_credits_value(credits or UNLIMITED))
     if jobs is None and role in (None, "user", "member"):
         quota = None
     else:
@@ -658,8 +665,7 @@ async def add_cluster_user(
         cluster_name,
         user_name,
         _ClusterUserRoleType(role),
-        org_name=org,
-        balance=balance,
+        org_name=_get_org_or_none(root, org),
         quota=quota,
     )
     assert user.role
@@ -676,9 +682,7 @@ async def add_cluster_user(
             markup=True,
         )
         quota_fmt = AdminQuotaFormatter()
-        balance_fmt = BalanceFormatter()
         root.print(quota_fmt(user.quota))
-        root.print(balance_fmt(user.balance))
 
 
 @command()
@@ -702,10 +706,10 @@ async def update_cluster_user(
     cluster_name: str,
     user_name: str,
     role: str,
-    org: Optional[str],
+    org: str | None,
 ) -> None:
     cluster_user = await root.client._admin.get_cluster_user(
-        cluster_name, user_name, org_name=org
+        cluster_name, user_name, org_name=_get_org_or_none(root, org)
     )
     cluster_user = replace(cluster_user, role=_ClusterUserRoleType(role))
     await root.client._admin.update_cluster_user(cluster_user)
@@ -735,13 +739,13 @@ def _parse_finite_decimal(value: str) -> Decimal:
     raise click.BadParameter(f"{value} is not valid decimal number")
 
 
-def _parse_credits_value(value: str) -> Optional[Decimal]:
+def _parse_credits_value(value: str) -> Decimal | None:
     if value == UNLIMITED:
         return None
     return _parse_finite_decimal(value)
 
 
-def _parse_jobs_value(value: str) -> Optional[int]:
+def _parse_jobs_value(value: str) -> int | None:
     if value == UNLIMITED:
         return None
     try:
@@ -764,12 +768,14 @@ def _parse_jobs_value(value: str) -> Optional[int]:
     help="org name for org-cluster users",
 )
 async def remove_cluster_user(
-    root: Root, cluster_name: str, user_name: str, org: Optional[str]
+    root: Root, cluster_name: str, user_name: str, org: str | None
 ) -> None:
     """
     Remove user access from the cluster.
     """
-    await root.client._admin.delete_cluster_user(cluster_name, user_name, org_name=org)
+    await root.client._admin.delete_cluster_user(
+        cluster_name, user_name, org_name=_get_org_or_none(root, org)
+    )
     if not root.quiet:
         root.print(
             f"Removed [bold]{rich_escape(user_name)}[/bold] "
@@ -786,31 +792,29 @@ async def remove_cluster_user(
 @command()
 @argument("cluster_name", required=True, type=str)
 @argument("user_name", required=True, type=str)
-@option(
-    "--org",
-    metavar="ORG",
-    default=None,
-    type=str,
-    help="org name for org-cluster users",
-)
+@argument("org", required=True, type=str)
 async def get_user_quota(
     root: Root,
     cluster_name: str,
     user_name: str,
-    org: Optional[str],
+    org: str,
 ) -> None:
     """
     Get info about user quota in given cluster
     """
-    user_with_quota = await root.client._admin.get_cluster_user(
+    org_name = _get_org(root, org)
+    cluster_user = await root.client._admin.get_cluster_user(
         cluster_name=cluster_name,
         user_name=user_name,
-        org_name=org,
+        org_name=org_name,
+    )
+    org_user = await root.client._admin.get_org_user(
+        org_name=org_name, user_name=user_name
     )
     quota_fmt = AdminQuotaFormatter()
     balance_fmt = BalanceFormatter()
     root.print(
-        f"Quota and balance for [u]{rich_escape(user_with_quota.user_name)}[/u] "
+        f"Quota and balance for [u]{rich_escape(cluster_user.user_name)}[/u] "
         + (
             f"as member of org [bold]{rich_escape(org)}[/bold] "
             if org is not None
@@ -819,8 +823,8 @@ async def get_user_quota(
         + f"on cluster [u]{rich_escape(cluster_name)}[/u]:",
         markup=True,
     )
-    root.print(quota_fmt(user_with_quota.quota))
-    root.print(balance_fmt(user_with_quota.balance))
+    root.print(quota_fmt(cluster_user.quota))
+    root.print(balance_fmt(org_user.balance))
 
 
 @command()
@@ -846,7 +850,7 @@ async def set_user_quota(
     cluster_name: str,
     user_name: str,
     jobs: str,
-    org: Optional[str],
+    org: str | None,
 ) -> None:
     """
     Set user quota to given values
@@ -855,7 +859,7 @@ async def set_user_quota(
         cluster_name=cluster_name,
         user_name=user_name,
         quota=_Quota(total_running_jobs=_parse_jobs_value(jobs)),
-        org_name=org,
+        org_name=_get_org_or_none(root, org),
     )
     fmt = AdminQuotaFormatter()
     root.print(
@@ -872,7 +876,7 @@ async def set_user_quota(
 
 
 @command()
-@argument("cluster_name", required=True, type=str)
+@argument("org", required=True, type=str)
 @argument("user_name", required=True, type=str)
 @option(
     "-c",
@@ -882,46 +886,33 @@ async def set_user_quota(
     required=True,
     help="Credits amount to set (`unlimited' stands for no limit)",
 )
-@option(
-    "--org",
-    metavar="ORG",
-    default=None,
-    type=str,
-    help="org name for org-cluster users",
-)
 async def set_user_credits(
     root: Root,
-    cluster_name: str,
+    org: str,
     user_name: str,
     credits: str,
-    org: Optional[str],
 ) -> None:
     """
     Set user credits to given value
     """
+    org_name = _get_org(root, org)
     credits_decimal = _parse_credits_value(credits)
-    user_with_quota = await root.client._admin.update_cluster_user_balance(
-        cluster_name=cluster_name,
+    user_with_quota = await root.client._admin.update_org_user_balance(
         user_name=user_name,
         credits=credits_decimal,
-        org_name=org,
+        org_name=org_name,
     )
     fmt = BalanceFormatter()
     root.print(
         f"New credits for [u]{rich_escape(user_with_quota.user_name)}[/u] "
-        + (
-            f"as member of org [bold]{rich_escape(org)}[/bold] "
-            if org is not None
-            else ""
-        )
-        + f"on cluster [u]{rich_escape(cluster_name)}[/u]:",
+        + f"as member of org [bold]{rich_escape(org)}[/bold]:",
         markup=True,
     )
     root.print(fmt(user_with_quota.balance))
 
 
 @command()
-@argument("cluster_name", required=True, type=str)
+@argument("org", required=True, type=str)
 @argument("user_name", required=True, type=str)
 @option(
     "-c",
@@ -931,39 +922,19 @@ async def set_user_credits(
     required=True,
     help="Credits amount to add",
 )
-@option(
-    "--org",
-    metavar="ORG",
-    default=None,
-    type=str,
-    help="org name for org-cluster users",
-)
-async def add_user_credits(
-    root: Root,
-    cluster_name: str,
-    user_name: str,
-    credits: str,
-    org: Optional[str],
-) -> None:
+async def add_user_credits(root: Root, org: str, user_name: str, credits: str) -> None:
     """
-    Add given values to user quota
+    Add given values to user credits
     """
+    org_name = _get_org(root, org)
     additional_credits = _parse_finite_decimal(credits)
-    user_with_quota = await root.client._admin.update_cluster_user_balance_by_delta(
-        cluster_name,
-        user_name,
-        delta=additional_credits,
-        org_name=org,
+    user_with_quota = await root.client._admin.update_org_user_balance_by_delta(
+        org_name, user_name, delta=additional_credits
     )
     fmt = BalanceFormatter()
     root.print(
         f"New credits for [u]{rich_escape(user_with_quota.user_name)}[/u] "
-        + (
-            f"as member of org [bold]{rich_escape(org)}[/bold] "
-            if org is not None
-            else ""
-        )
-        + f"on cluster [u]{rich_escape(cluster_name)}[/u]:",
+        + f"as member of org [bold]{rich_escape(org)}[/bold]:",
         markup=True,
     )
     root.print(fmt(user_with_quota.balance))
@@ -1016,6 +987,27 @@ async def add_user_credits(
     type=int,
     help="Number of Intel GPUs",
 )
+@option(
+    "--nvidia-gpu-model",
+    metavar="GPU_MODEL_FREE_TEXT",
+    type=str,
+    help="Nvidia GPU model",
+    required=False,
+)
+@option(
+    "--amd-gpu-model",
+    metavar="GPU_MODEL_FREE_TEXT",
+    type=str,
+    help="AMD GPU model",
+    required=False,
+)
+@option(
+    "--intel-gpu-model",
+    metavar="GPU_MODEL_FREE_TEXT",
+    type=str,
+    help="Intel GPU model",
+    required=False,
+)
 @option("--tpu-type", metavar="TYPE", type=str, help="TPU type")
 @option(
     "tpu_software_version",
@@ -1053,11 +1045,14 @@ async def add_resource_preset(
     credits_per_hour: str,
     cpu: float,
     memory: int,
-    nvidia_gpu: Optional[int],
-    amd_gpu: Optional[int],
-    intel_gpu: Optional[int],
-    tpu_type: Optional[str],
-    tpu_software_version: Optional[str],
+    nvidia_gpu: int | None,
+    amd_gpu: int | None,
+    intel_gpu: int | None,
+    nvidia_gpu_model: str | None,
+    amd_gpu_model: str | None,
+    intel_gpu_model: str | None,
+    tpu_type: str | None,
+    tpu_software_version: str | None,
     scheduler: bool,
     preemptible_node: bool,
     resource_pool_names: Sequence[str],
@@ -1080,10 +1075,13 @@ async def add_resource_preset(
         nvidia_gpu=nvidia_gpu,
         amd_gpu=amd_gpu,
         intel_gpu=intel_gpu,
+        nvidia_gpu_model=nvidia_gpu_model,
+        amd_gpu_model=amd_gpu_model,
+        intel_gpu_model=intel_gpu_model,
         tpu=tpu_preset,
         scheduler_enabled=scheduler,
         preemptible_node=preemptible_node,
-        resource_pool_names=resource_pool_names,
+        resource_pool_names=tuple(resource_pool_names),
     )
     await root.client._clusters.add_resource_preset(
         root.client.config.cluster_name, preset
@@ -1138,6 +1136,24 @@ async def add_resource_preset(
     type=int,
     help="Number of Intel GPUs",
 )
+@option(
+    "--nvidia-gpu-model",
+    metavar="GPU_MODEL_FREE_TEXT",
+    type=str,
+    help="Nvidia GPU model",
+)
+@option(
+    "--amd-gpu-model",
+    metavar="GPU_MODEL_FREE_TEXT",
+    type=str,
+    help="AMD GPU model",
+)
+@option(
+    "--intel-gpu-model",
+    metavar="GPU_MODEL_FREE_TEXT",
+    type=str,
+    help="Intel GPU model",
+)
 @option("--tpu-type", metavar="TYPE", type=str, help="TPU type")
 @option(
     "tpu_software_version",
@@ -1170,16 +1186,19 @@ async def add_resource_preset(
 async def update_resource_preset(
     root: Root,
     preset_name: str,
-    credits_per_hour: Optional[str],
-    cpu: Optional[float],
-    memory: Optional[int],
-    nvidia_gpu: Optional[int],
-    amd_gpu: Optional[int],
-    intel_gpu: Optional[int],
-    tpu_type: Optional[str],
-    tpu_software_version: Optional[str],
-    scheduler: Optional[bool],
-    preemptible_node: Optional[bool],
+    credits_per_hour: str | None,
+    cpu: float | None,
+    memory: int | None,
+    nvidia_gpu: int | None,
+    amd_gpu: int | None,
+    intel_gpu: int | None,
+    nvidia_gpu_model: str | None,
+    amd_gpu_model: str | None,
+    intel_gpu_model: str | None,
+    tpu_type: str | None,
+    tpu_software_version: str | None,
+    scheduler: bool | None,
+    preemptible_node: bool | None,
     resource_pool_names: Sequence[str],
 ) -> None:
     """
@@ -1191,7 +1210,7 @@ async def update_resource_preset(
     except KeyError:
         raise ValueError(f"Preset '{preset_name}' does not exists")
 
-    kwargs: Dict[str, Any] = {
+    kwargs: dict[str, Any] = {
         "credits_per_hour": (
             _parse_finite_decimal(credits_per_hour)
             if credits_per_hour is not None
@@ -1202,6 +1221,9 @@ async def update_resource_preset(
         "nvidia_gpu": nvidia_gpu,
         "amd_gpu": amd_gpu,
         "intel_gpu": intel_gpu,
+        "nvidia_gpu_model": nvidia_gpu_model,
+        "amd_gpu_model": amd_gpu_model,
+        "intel_gpu_model": intel_gpu_model,
         "tpu_type": tpu_type,
         "tpu_software_version": tpu_software_version,
         "scheduler_enabled": scheduler,
@@ -1226,6 +1248,9 @@ async def update_resource_preset(
             nvidia_gpu=preset.nvidia_gpu,
             amd_gpu=preset.amd_gpu,
             intel_gpu=preset.intel_gpu,
+            nvidia_gpu_model=preset.nvidia_gpu_model,
+            amd_gpu_model=preset.amd_gpu_model,
+            intel_gpu_model=preset.intel_gpu_model,
             tpu=tpu_preset,
             scheduler_enabled=preset.scheduler_enabled,
             preemptible_node=preset.preemptible_node,
@@ -1290,6 +1315,7 @@ async def add_org(
     await root.client._admin.create_org(
         org_name, skip_auto_add_to_clusters=skip_default_tenants
     )
+    await root.client.config.fetch()
 
 
 @command()
@@ -1338,21 +1364,37 @@ async def get_org_users(root: Root, org_name: str) -> None:
     metavar="[ROLE]",
     type=click.Choice([str(role) for role in list(_OrgUserRoleType)]),
 )
+@option(
+    "-c",
+    "--credits",
+    metavar="AMOUNT",
+    type=str,
+    default=None,
+    show_default=True,
+    help="Credits amount to set (`unlimited' stands for no limit)",
+)
 async def add_org_user(
     root: Root,
     org_name: str,
     user_name: str,
     role: str,
+    credits: str | None,
 ) -> None:
     """
     Add user access to specified org.
 
-    The command supports one of 3 user roles: admin, manager or user.
+    The command supports one of three user roles: admin, manager or user.
     """
+    if credits is None and role == "user":
+        balance = None
+    else:
+        balance = _Balance(credits=_parse_credits_value(credits or UNLIMITED))
+
     user = await root.client._admin.create_org_user(
-        org_name,
-        user_name,
-        _OrgUserRoleType(role),
+        org_name=org_name,
+        user_name=user_name,
+        role=_OrgUserRoleType(role),
+        balance=balance,
     )
     if not root.quiet:
         root.print(
@@ -1361,6 +1403,8 @@ async def add_org_user(
             f"[bold]{rich_escape(user.role)}[/bold]",
             markup=True,
         )
+        balance_fmt = BalanceFormatter()
+        root.print(balance_fmt(user.balance))
 
 
 @command()
@@ -1454,7 +1498,7 @@ async def add_org_cluster(
     default_credits: str,
     default_jobs: str,
     default_role: str,
-    storage_size: Optional[int],
+    storage_size: int | None,
 ) -> None:
     """
     Add org access to specified cluster.
@@ -1704,8 +1748,7 @@ async def set_org_cluster_quota(
 
 
 @command()
-@argument("cluster_name", required=True, type=str)
-@argument("org_name", required=True, type=str)
+@argument("org", required=True, type=str)
 @option(
     "-c",
     "--credits",
@@ -1714,33 +1757,30 @@ async def set_org_cluster_quota(
     required=True,
     help="Credits amount to set (`unlimited' stands for no limit)",
 )
-async def set_org_cluster_credits(
+async def set_org_credits(
     root: Root,
-    cluster_name: str,
-    org_name: str,
+    org: str,
     credits: str,
 ) -> None:
     """
-    Set org cluster credits to given value
+    Set org credits to given value
     """
+    org_name = _get_org(root, org)
     credits_decimal = _parse_credits_value(credits)
-    org = await root.client._admin.update_org_cluster_balance(
-        cluster_name=cluster_name,
+    updated_org = await root.client._admin.update_org_balance(
         org_name=org_name,
         credits=credits_decimal,
     )
     fmt = BalanceFormatter()
     root.print(
-        f"New credits for org [u]{rich_escape(org_name)}[/u] "
-        + f"on cluster [u]{rich_escape(cluster_name)}[/u]:",
+        f"New credits for org [u]{rich_escape(org_name)}[/u] ",
         markup=True,
     )
-    root.print(fmt(org.balance))
+    root.print(fmt(updated_org.balance))
 
 
 @command()
-@argument("cluster_name", required=True, type=str)
-@argument("org_name", required=True, type=str)
+@argument("org", required=True, type=str)
 @option(
     "-c",
     "--credits",
@@ -1748,29 +1788,60 @@ async def set_org_cluster_credits(
     type=str,
     help="Credits amount to add",
 )
-async def add_org_cluster_credits(
+async def add_org_credits(
     root: Root,
-    cluster_name: str,
-    org_name: str,
+    org: str,
     credits: str,
 ) -> None:
     """
-    Add given values to org cluster balance
+    Add given values to org balance
     """
+    org_name = _get_org(root, org)
     additional_credits = _parse_finite_decimal(credits)
     assert additional_credits
-    org = await root.client._admin.update_org_cluster_balance_by_delta(
-        cluster_name,
+    updated_org = await root.client._admin.update_org_balance_by_delta(
         org_name,
         delta=additional_credits,
     )
     fmt = BalanceFormatter()
     root.print(
-        f"New credits for org [u]{rich_escape(org_name)}[/u] "
-        + f"on cluster [u]{rich_escape(cluster_name)}[/u]:",
+        f"New credits for org [u]{rich_escape(org_name)}[/u] ",
         markup=True,
     )
-    root.print(fmt(org.balance))
+    root.print(fmt(updated_org.balance))
+
+
+@command()
+@argument("org_name", required=True, type=str)
+@option(
+    "--user-default-credits",
+    metavar="AMOUNT",
+    type=str,
+    default=UNLIMITED,
+    show_default=True,
+    help="Default credits amount to set for org users "
+    "(`unlimited' stands for no limit)",
+)
+async def set_org_defaults(
+    root: Root,
+    org_name: str,
+    user_default_credits: str,
+) -> None:
+    """
+    Set org defaults to a given value
+    """
+    org = await root.client._admin.update_org_defaults(
+        org_name=org_name,
+        user_default_credits=_parse_credits_value(user_default_credits),
+    )
+    if not root.quiet:
+        root.print(
+            f"Org [bold]{rich_escape(org_name)}[/bold] successfully updated. "
+            f"New info:",
+            markup=True,
+        )
+        fmt = OrgFormatter()
+        root.print(fmt(org))
 
 
 # Projects
@@ -1785,16 +1856,14 @@ async def add_org_cluster_credits(
     type=str,
     help="org name for org-cluster projects",
 )
-async def get_projects(
-    root: Root, cluster_name: str, org: Optional[str] = None
-) -> None:
+async def get_projects(root: Root, cluster_name: str, org: str | None = None) -> None:
     """
     Print the list of all projects in the cluster
     """
     fmt = ProjectsFormatter()
     with root.status(f"Fetching the list of projects of cluster [b]{cluster_name}[/b]"):
         org_clusters = await root.client._admin.list_projects(
-            cluster_name=cluster_name, org_name=org
+            cluster_name=cluster_name, org_name=_get_org_or_none(root, org)
         )
     with root.pager():
         root.print(fmt(org_clusters))
@@ -1828,7 +1897,7 @@ async def add_project(
     root: Root,
     name: str,
     cluster_name: str,
-    org: Optional[str],
+    org: str | None,
     default_role: str,
     default: bool = False,
 ) -> None:
@@ -1840,7 +1909,7 @@ async def add_project(
     project = await root.client._admin.create_project(
         name=name,
         cluster_name=cluster_name,
-        org_name=org,
+        org_name=_get_org_or_none(root, org),
         default_role=_ProjectUserRoleType(default_role),
         is_default=default,
     )
@@ -1893,7 +1962,7 @@ async def update_project(
     root: Root,
     name: str,
     cluster_name: str,
-    org: Optional[str],
+    org: str | None,
     default_role: str,
     default: bool = False,
 ) -> None:
@@ -1904,7 +1973,7 @@ async def update_project(
     project = _Project(
         name=name,
         cluster_name=cluster_name,
-        org_name=org,
+        org_name=_get_org_or_none(root, org),
         default_role=_ProjectUserRoleType(default_role),
         is_default=default,
     )
@@ -1933,7 +2002,7 @@ async def update_project(
     help="org name for org-cluster projects",
 )
 async def remove_project(
-    root: Root, name: str, cluster_name: str, org: Optional[str], force: bool
+    root: Root, name: str, cluster_name: str, org: str | None, force: bool
 ) -> None:
     """
     Drop a project
@@ -1950,7 +2019,9 @@ async def remove_project(
         if answer != "y":
             return
     await root.client._admin.delete_project(
-        project_name=name, cluster_name=cluster_name, org_name=org
+        project_name=name,
+        cluster_name=cluster_name,
+        org_name=_get_org_or_none(root, org),
     )
 
 
@@ -1965,7 +2036,7 @@ async def remove_project(
     help="org name for org-cluster projects",
 )
 async def get_project_users(
-    root: Root, cluster_name: str, project_name: str, org: Optional[str]
+    root: Root, cluster_name: str, project_name: str, org: str | None
 ) -> None:
     """
     List users in specified project
@@ -1977,7 +2048,7 @@ async def get_project_users(
         users = await root.client._admin.list_project_users(
             project_name=project_name,
             cluster_name=cluster_name,
-            org_name=org,
+            org_name=_get_org_or_none(root, org),
             with_user_info=True,
         )
     with root.pager():
@@ -2006,9 +2077,9 @@ async def add_project_user(
     root: Root,
     cluster_name: str,
     project_name: str,
-    org: Optional[str],
+    org: str | None,
     user_name: str,
-    role: Optional[None],
+    role: None | None,
 ) -> None:
     """
     Add user access to specified project.
@@ -2018,7 +2089,7 @@ async def add_project_user(
     user = await root.client._admin.create_project_user(
         project_name=project_name,
         cluster_name=cluster_name,
-        org_name=org,
+        org_name=_get_org_or_none(root, org),
         user_name=user_name,
         role=_ProjectUserRoleType(role) if role else None,
     )
@@ -2052,7 +2123,7 @@ async def update_project_user(
     root: Root,
     cluster_name: str,
     project_name: str,
-    org: Optional[str],
+    org: str | None,
     user_name: str,
     role: str,
 ) -> None:
@@ -2064,7 +2135,7 @@ async def update_project_user(
     user = _ProjectUser(
         project_name=project_name,
         cluster_name=cluster_name,
-        org_name=org,
+        org_name=_get_org_or_none(root, org),
         user_name=user_name,
         role=_ProjectUserRoleType(role),
     )
@@ -2094,7 +2165,7 @@ async def remove_project_user(
     root: Root,
     cluster_name: str,
     project_name: str,
-    org: Optional[str],
+    org: str | None,
     user_name: str,
 ) -> None:
     """
@@ -2103,7 +2174,7 @@ async def remove_project_user(
     await root.client._admin.delete_project_user(
         project_name=project_name,
         cluster_name=cluster_name,
-        org_name=org,
+        org_name=_get_org_or_none(root, org),
         user_name=user_name,
     )
     if not root.quiet:
@@ -2153,8 +2224,9 @@ admin.add_command(remove_org_cluster)
 admin.add_command(set_org_cluster_defaults)
 admin.add_command(get_org_cluster_quota)
 admin.add_command(set_org_cluster_quota)
-admin.add_command(set_org_cluster_credits)
-admin.add_command(add_org_cluster_credits)
+admin.add_command(set_org_credits)
+admin.add_command(add_org_credits)
+admin.add_command(set_org_defaults)
 
 admin.add_command(get_projects)
 admin.add_command(add_project)
