@@ -12,7 +12,7 @@ import pytest
 from rich.console import Console, RenderableType
 from yarl import URL
 
-from apolo_sdk import Cluster, Factory, Preset, Project, ResourcePool
+from apolo_sdk import AppsConfig, Cluster, Factory, Preset, Project, ResourcePool
 from apolo_sdk._config import _AuthConfig, _AuthToken, _ConfigData
 
 from apolo_cli import __version__
@@ -29,13 +29,13 @@ log = logging.getLogger(__name__)
 def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
     nmrc_path = tmp_path / "conftest.nmrc"
     cluster_config = Cluster(
-        registry_url=URL("https://registry-dev.neu.ro"),
-        storage_url=URL("https://storage-dev.neu.ro"),
-        users_url=URL("https://users-dev.neu.ro"),
-        monitoring_url=URL("https://monitoring-dev.neu.ro"),
-        secrets_url=URL("https://secrets-dev.neu.ro"),
-        disks_url=URL("https://disks-dev.neu.ro"),
-        buckets_url=URL("https://buckets-dev.neu.ro"),
+        registry_url=URL("https://registry-api.dev.apolo.us"),
+        storage_url=URL("https://storage-api.dev.apolo.us"),
+        users_url=URL("https://users-api.dev.apolo.us"),
+        monitoring_url=URL("https://monitoring-api.dev.apolo.us"),
+        secrets_url=URL("https://secrets-api.dev.apolo.us"),
+        disks_url=URL("https://disks-api.dev.apolo.us"),
+        buckets_url=URL("https://buckets-api.dev.apolo.us"),
         resource_pools={
             "cpu": ResourcePool(
                 min_size=1,
@@ -51,6 +51,7 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
                 memory=60 * 2**30,
                 disk_size=150 * 2**30,
                 nvidia_gpu=1,
+                nvidia_gpu_model="nvidia-tesla-k80",
             ),
             "amd-gpu": ResourcePool(
                 min_size=0,
@@ -59,6 +60,7 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
                 memory=60 * 2**30,
                 disk_size=150 * 2**30,
                 amd_gpu=1,
+                amd_gpu_model="instinct-mi25",
             ),
             "intel-gpu": ResourcePool(
                 min_size=0,
@@ -67,6 +69,7 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
                 memory=60 * 2**30,
                 disk_size=150 * 2**30,
                 intel_gpu=1,
+                intel_gpu_model="flex-170",
             ),
         },
         presets={
@@ -75,42 +78,48 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
                 cpu=7,
                 memory=30 * 2**30,
                 nvidia_gpu=1,
-                resource_pool_names=["nvidia-gpu"],
+                nvidia_gpu_model="nvidia-tesla-k80",
+                resource_pool_names=("nvidia-gpu",),
             ),
             "nvidia-gpu-large": Preset(
                 credits_per_hour=Decimal("10"),
                 cpu=7,
                 memory=60 * 2**30,
                 nvidia_gpu=1,
-                resource_pool_names=["nvidia-gpu"],
+                nvidia_gpu_model="nvidia-A100",
+                resource_pool_names=("nvidia-gpu",),
             ),
             "amd-gpu-small": Preset(
                 credits_per_hour=Decimal("10"),
                 cpu=7,
                 memory=30 * 2**30,
                 amd_gpu=1,
-                resource_pool_names=["amd-gpu"],
+                amd_gpu_model="instinct-mi25",
+                resource_pool_names=("amd-gpu",),
             ),
             "amd-gpu-large": Preset(
                 credits_per_hour=Decimal("10"),
                 cpu=7,
                 memory=60 * 2**30,
                 amd_gpu=1,
-                resource_pool_names=["amd-gpu"],
+                amd_gpu_model="instinct-mi100",
+                resource_pool_names=("amd-gpu",),
             ),
             "intel-gpu-small": Preset(
                 credits_per_hour=Decimal("10"),
                 cpu=7,
                 memory=30 * 2**30,
                 intel_gpu=1,
-                resource_pool_names=["intel-gpu"],
+                intel_gpu_model="flex-170",
+                resource_pool_names=("intel-gpu",),
             ),
             "intel-gpu-large": Preset(
                 credits_per_hour=Decimal("10"),
                 cpu=7,
                 memory=60 * 2**30,
                 intel_gpu=1,
-                resource_pool_names=["intel-gpu"],
+                intel_gpu_model="max-1550",
+                resource_pool_names=("intel-gpu",),
             ),
             "cpu-small": Preset(
                 credits_per_hour=Decimal("10"),
@@ -124,16 +133,17 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
             ),
         },
         name="default",
-        orgs=[None, "org"],
+        orgs=["NO_ORG", "org"],
+        apps=AppsConfig(),
     )
     cluster2_config = Cluster(
-        registry_url=URL("https://registry2-dev.neu.ro"),
-        storage_url=URL("https://storage2-dev.neu.ro"),
-        users_url=URL("https://users2-dev.neu.ro"),
-        monitoring_url=URL("https://monitoring2-dev.neu.ro"),
-        secrets_url=URL("https://secrets2-dev.neu.ro"),
-        disks_url=URL("https://disks2-dev.neu.ro"),
-        buckets_url=URL("https://buckets2-dev.neu.ro"),
+        registry_url=URL("https://registry2-api.dev.apolo.us"),
+        storage_url=URL("https://storage2-api.dev.apolo.us"),
+        users_url=URL("https://users2-api.dev.apolo.us"),
+        monitoring_url=URL("https://monitoring2-api.dev.apolo.us"),
+        secrets_url=URL("https://secrets2-api.dev.apolo.us"),
+        disks_url=URL("https://disks2-api.dev.apolo.us"),
+        buckets_url=URL("https://buckets2-api.dev.apolo.us"),
         resource_pools={
             "cpu": ResourcePool(
                 min_size=1,
@@ -151,13 +161,14 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
             ),
         },
         name="other",
-        orgs=[None],
+        orgs=["NO_ORG"],
+        apps=AppsConfig(),
     )
     config = _ConfigData(
         auth_config=auth_config,
         auth_token=_AuthToken.create_non_expiring(token),
-        url=URL("https://dev.neu.ro/api/v1"),
-        admin_url=URL("https://dev.neu.ro/apis/admin/v1"),
+        url=URL("https://api.dev.apolo.us/api/v1"),
+        admin_url=URL("https://api.dev.apolo.us/apis/admin/v1"),
         version=__version__,
         cluster_name=cluster_config.name,
         org_name=cluster_config.orgs[0],
@@ -178,31 +189,31 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
             ),
             Project.Key(
                 cluster_name=cluster_config.name,
-                org_name=None,
+                org_name="NO_ORG",
                 project_name="user",
             ): Project(
                 cluster_name=cluster_config.name,
-                org_name=None,
+                org_name="NO_ORG",
                 name="user",
                 role="admin",
             ),
             Project.Key(
                 cluster_name=cluster_config.name,
-                org_name=None,
+                org_name="NO_ORG",
                 project_name="otherproject",
             ): Project(
                 cluster_name=cluster_config.name,
-                org_name=None,
+                org_name="NO_ORG",
                 name="otherproject",
                 role="admin",
             ),
             Project.Key(
                 cluster_name=cluster2_config.name,
-                org_name=None,
+                org_name="NO_ORG",
                 project_name="user",
             ): Project(
                 cluster_name=cluster2_config.name,
-                org_name=None,
+                org_name="NO_ORG",
                 name="user",
                 role="admin",
             ),
@@ -255,8 +266,12 @@ def root_no_logged_in(tmp_path: Path) -> Iterator[Root]:
 
 @pytest.fixture()
 def run_cli(
-    nmrc_path: Path, capfd: Any, tmp_path: Path
+    nmrc_path: Path, capfd: Any, tmp_path: Path, monkeypatch: Any
 ) -> Callable[[List[str]], SysCapWithCode]:
+    monkeypatch.setattr(
+        "apolo_cli.file_logging.get_handler", lambda: logging.NullHandler()
+    )
+
     def _run_cli(arguments: List[str]) -> SysCapWithCode:
         log.info("Run 'apolo %s'", " ".join(arguments))
         capfd.readouterr()
@@ -385,8 +400,7 @@ class RichComparator:
                 f"The reference {rel_ref} doesn't exist.\n"
                 "Create it yourself or run pytest with '--rich-gen' option."
             )
-        else:
-            return self.read_file(ref)
+        return self.read_file(ref)
 
     def write_file(self, ref: Path, buf: str) -> None:
         ref.parent.mkdir(parents=True, exist_ok=True)
